Learn R Programming

FTSgof (version 1.0.0)

dgp.ou: Ornstein–Uhlenbeck Process Generator

Description

It generates iid functional curve data following the Ornstein–Uhlenbeck process.

Usage

dgp.ou(J, N)

Value

A (grid points) x (number of observations) matrix for iid sequences, where the finite realization of curves are stored in columns.

Arguments

J

The number of grid points in each curve observation.

N

The sample size.

Details

The Ornstein–Uhlenbeck process is given by: \(x_i(t)=e^{-t/2}W_i(e^t)\), \(t \in [0,1]\),
where \(W_i(t)\) is a standard Brownian Motion.

Examples

Run this code

# \donttest{
# Generate discrete evaluations of 100 iid curves
# that each curve is realized on 50 grid points.
yd_ou = dgp.ou(J = 50, N = 100)
# }

Run the code above in your browser using DataLab