powered by
It generates iid functional curve data following the Ornstein–Uhlenbeck process.
dgp.ou(J, N)
A (grid points) x (number of observations) matrix for iid sequences, where the finite realization of curves are stored in columns.
The number of grid points in each curve observation.
The sample size.
The Ornstein–Uhlenbeck process is given by: \(x_i(t)=e^{-t/2}W_i(e^t)\), \(t \in [0,1]\), where \(W_i(t)\) is a standard Brownian Motion.
# \donttest{ # Generate discrete evaluations of 100 iid curves # that each curve is realized on 50 grid points. yd_ou = dgp.ou(J = 50, N = 100) # }
Run the code above in your browser using DataLab